@@ -171,6 +171,7 @@ class NumerousLogHandler:
         self.debounce = 5
 
     def handle(self, record):
+
         now_ = datetime.utcnow()
         #print(record)
         self.buffered_records.append((now_, record.msg))
@@ -181,9 +182,11 @@ class NumerousLogHandler:
 
 
     def flush(self):
-        #print('recs: ', self.buffered_records)
-        self.client.push_scenario_logs(self.buffered_records)
-        self.buffered_records=[]
+
+        to_push = self.buffered_records.copy()
+        self.buffered_records = []
+        self.client.push_scenario_logs(to_push)
+
 
     # TODO make a handler thread to schedule update to server!
 
@@ -214,7 +217,7 @@ class NumerousClient:
         # Refresh token every 9 minutes (?)
         self._access_token_refresher = RepeatedFunction(
             interval=9*60, function=self._refresh_access_token, run_initially=True,
-            refresh_token=self._refresh_token, instance_id=self._instance_id, execution_id=self._execution_id
+            refresh_token=self._refresh_token, instance_id=self._instance_id, execution_id=self._execution_id, project_id=self._project, scenario_id=self._scenario, job_id=self._job_id
         )
         self._access_token_refresher.start()
 
@@ -275,10 +278,10 @@ class NumerousClient:
         self.log_listener = logging.handlers.QueueListener(log_queue, self.log_handler)
         self.log_listener.start()
 
-    def _refresh_access_token(self, refresh_token, instance_id, execution_id):
+    def _refresh_access_token(self, refresh_token, instance_id, execution_id, project_id=None, scenario_id=None, job_id=None):
         token = self._token_manager.GetAccessToken(
             spm_pb2.RefreshRequest(
-                refresh_token=spm_pb2.Token(val=refresh_token), instance_id=instance_id, execution_id=execution_id
+                refresh_token=spm_pb2.Token(val=refresh_token), instance_id=instance_id, execution_id=execution_id,project_id=project_id, scenario_id=scenario_id, job_id=job_id
             )
         )
         self._access_token = token.val
@@ -493,9 +496,10 @@ class NumerousClient:
 
         return self._base_client.GetScenarioMetaData(spm_pb2.Scenario(scenario=scenario))
 
-    def set_timeseries_meta_data(self, tags, aliases, offset=0, timezone='UTC', epoch_type='s', scenario= None):
+    def set_timeseries_meta_data(self, tags:list, aliases:dict={}, offset=0, timezone='UTC', epoch_type='s', scenario= None):
 
         def g(tag, key, def_):
+
             if key in tag:
                 return tag[key]
             elif def_ is not None:
@@ -514,7 +518,7 @@ class NumerousClient:
                 'scaling': 1,
                 'offset': 0
             }.items()}
-            print(kwargs)
+
             return spm_pb2.Tag(
                 **kwargs
             )
